@@ -19,7 +19,7 @@ set_radius <- function(W, y, family = "gaussian", no_radii,
 
   # First run the naive Lasso
   lassoFit <- glmnet::cv.glmnet(W, y, family = family)
-  betaNaive <- glmnet::coef.cv.glmnet(lassoFit, s = "lambda.min")
+  betaNaive <- stats::coef(lassoFit, s = "lambda.min")
 
   # Use the estimated vector to find the upper radius for cross-validation
   a <- sum( abs( betaNaive ) )
@@ -29,18 +29,10 @@ set_radius <- function(W, y, family = "gaussian", no_radii,
 
 }
 
-#
-# get_radii <- function(W, y, family, no_radii,
-#                       lower_limit_factor = 1e-6, upper_limit_factor = 2) {
-#   no_radii <- ifelse(is.null(no_radii), 20, no_radii)
-#   # First run the naive Lasso
-#   lassoFit <- glmnet::cv.glmnet(W, y, family = family)
-#   betaNaive <- glmnet::coef.cv.glmnet(lassoFit, s = "lambda.min")
-#
-#   # Use the estimated vector to find the upper radii for cross-validation
-#   ul <- upper_limit_factor * sum( abs( betaNaive ) )
-#   ll <- lower_limit_factor * sum( abs( betaNaive ) )
-#
-#   # Set the cross-validation range
-#   seq(from = ll, to = ul, length.out = no_radii)
-# }
+
+set_up_cv <- function(N, n_folds){
+  list(
+    fold_id = sample(rep(seq(n_folds), length = N)),
+    outlist = as.list(seq(n_folds))
+  )
+}
